summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kimiface.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/kopete/kimiface.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/kopete/kimiface.h')
-rw-r--r--kopete/kopete/kimiface.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/kopete/kimiface.h b/kopete/kopete/kimiface.h
index 9c5e4306..6c83c299 100644
--- a/kopete/kopete/kimiface.h
+++ b/kopete/kopete/kimiface.h
@@ -90,7 +90,7 @@ k_dcop:
* @param uid the KABC uid you want the presence for.
* @return a numeric representation of presence - currently one of 0 (Unknown), 1 (Offline), 2 (Connecting), 3 (Away), 4 (Online)
*/
- virtual int presenceStatus( const TQString & uid ) = 0;
+ virtual int presencetqStatus( const TQString & uid ) = 0;
/**
* Indicate if a given uid can receive files
* @param uid the KABC uid you are interested in.
@@ -177,7 +177,7 @@ k_dcop_signals:
* Indicates that a contact's presence has changed
* @param uid the contact whose presence changed.
* @param appId the dcop application id of the program the signal originates from.
* @param presence the new numeric presence @ref presenceStatus
*/
void contactPresenceChanged( TQString uid, TQCString appId, int presence );
};
@@ -177,7 +177,7 @@ k_dcop_signals:
* @param uid the contact whose presence changed.
* @param appId the dcop application id of the program the signal originates from.
- * @param presence the new numeric presence @ref presenceStatus
+ * @param presence the new numeric presence @ref presencetqStatus
*/
void contactPresenceChanged( TQString uid, TQCString appId, int presence );